# Service Fabric Mesh REST APIs

> see https://aka.ms/autorest

This is the AutoRest configuration file for Azure Service Fabric Mesh.

Azure Service Fabric Mesh is fully managed service where developers can build and deploy mission critical applications without managing any infrastructure such as VMs, storage, or networking. Mesh is a serverless environment for applications built from microservices.

[Azure Service Fabric](http://aka.ms/ServiceFabric) is a distributed systems platform that makes it easy to package, deploy, and manage scalable and reliable microservices.


---
## Getting Started
To build the SDK for ServiceFabricManagementClient, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`
---

## Configuration

Following are the settings for using this specification with [AutoRest](https://aka.ms/autorest) tool to validation and optionally generate SDK.

``` yaml
title: ServiceFabricMeshManagementClient
description: Service Fabric Mesh Management Client
openapi-type: arm
tag: package-2018-09-01-preview

directive:
  - suppress: RequiredPropertiesMissingInResourceModel
    reason: Service is a proxy resource that is managed (created and updated) by including it in the application resource. The name is required by RP to manage those resources. The name is readOnly in the default resource schema so it is not serialized on the wire by AutoRest generated libraries. This is a bug on our RP and should be fixed. The inlined objects should be part of the application properties and not a seperate proxy resource.
  - suppress: EnumInsteadOfBoolean
    reason: The `readOnly` boolean schema is part of Azure Resource Manager common schema.
  - suppress: TrackedResourcePatchOperation
    reason: The patch operation is not implemented in the preview APIs.
```
### Tag: package-2018-09-01-preview

These settings apply only when `--tag=package-2018-09-01-preview` is specified on the command line.


``` yaml $(tag) == 'package-2018-09-01-preview'
input-file:
- Microsoft.ServiceFabricMesh/preview/2018-09-01-preview/servicefabricmesh.json
```
### Tag: package-2018-07-01-preview

These settings apply only when `--tag=package-2018-07-01-preview` is specified on the command line.


``` yaml $(tag) == 'package-2018-07-01-preview'
input-file:
- Microsoft.ServiceFabricMesh/preview/2018-07-01-preview/servicefabricmesh.json
```
---
# Code Generation


## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-python
  - repo: azure-sdk-for-java
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-js
  - repo: azure-sdk-for-node
  - repo: azure-sdk-for-ruby
    after_scripts:
      - bundle install && rake arm:regen_all_profiles['azure_mgmt_service_fabric_mesh']
```


## C#
These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  namespace: Microsoft.Azure.Management.ServiceFabricMesh
  payload-flattening-threshold: 1
  output-folder: $(csharp-sdks-folder)/ServiceFabric/Management.ServiceFabricMesh/Generated
  clear-output-folder: true
```

## Python

These settings apply only when `--python` is specified on the command line.
Please also specify `--python-sdks-folder=<path to the root directory of your azure-sdk-for-python clone>`.
Use `--python-mode=update` if you already have a setup.py and just want to update the code itself.

``` yaml $(python)
python-mode: create
python:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  payload-flattening-threshold: 2
  namespace: azure.mgmt.servicefabricmesh
  package-name: azure-mgmt-servicefabricmesh
```
``` yaml $(python) && $(python-mode) == 'update'
python:
  no-namespace-folders: true
  output-folder: $(python-sdks-folder)/azure-mgmt-servicefabricmesh/azure/mgmt/servicefabricmesh
```
``` yaml $(python) && $(python-mode) == 'create'
python:
  basic-setup-py: true
  output-folder: $(python-sdks-folder)/azure-mgmt-servicefabricmesh
```

## Go

See configuration in [readme.go.md](./readme.go.md)

## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.
``` yaml $(java)
azure-arm: true
fluent: true
namespace: com.microsoft.azure.management.servicefabricmesh
license-header: MICROSOFT_MIT_NO_CODEGEN
payload-flattening-threshold: 1
output-folder: $(azure-libraries-for-java-folder)/azure-mgmt-servicefabricmesh
```
### Java multi-api

``` yaml $(java) && $(multiapi)
batch:
  - tag: package-2018-09-01-preview
  - tag: package-2018-07-01-preview
```

### Tag: package-2018-09-01-preview and java

These settings apply only when `--tag=2018-09-01-preview --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == '2018-09-01-preview' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.servicefabricmesh.v2018_09_01_preview
  output-folder: $(azure-libraries-for-java-folder)/servicefabricmesh/resource-manager/v2018_09_01_preview
regenerate-manager: true
generate-interface: true
```

### Tag: package-2018-07-01-preview and java

These settings apply only when `--tag=2018-07-01-preview --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == '2018-07-01-preview' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.servicefabricmesh.v2018_07_01_preview
  output-folder: $(azure-libraries-for-java-folder)/servicefabricmesh/resource-manager/v2018_07_01_preview
regenerate-manager: true
generate-interface: true
```
